#
# spec file for package gnome-themes-extra
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-themes-extra
Version:        3.28
Release:        2.5
Summary:        Extra GNOME Themes
License:        LGPL-2.1-or-later
Group:          System/GUI/GNOME
URL:            http://www.gnome.org
Source:         http://download.gnome.org/sources/gnome-themes-extra/3.28/%{name}-%{version}.tar.xz

BuildRequires:  fdupes
# Needed to convert svg to gresource
BuildRequires:  gdk-pixbuf-loader-rsvg
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gdk-2.0) >= 2.24.15
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gtk+-2.0) >= 2.24.15
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.9.12
BuildRequires:  pkgconfig(librsvg-2.0)

%description
This packages contains extra GNOME themes from GNOME 3 and later.

%package -n metatheme-adwaita-common
Summary:        Common files for the Adwaita GNOME theme
Group:          System/GUI/GNOME
Suggests:       gtk2-metatheme-adwaita
Suggests:       gtk3-metatheme-adwaita
BuildArch:      noarch

%description -n metatheme-adwaita-common
Adwaita is the default GNOME theme in GNOME 3.

# Note: it's really a metatheme, and not just a gtk2 theme as we require metatheme-adwaita-common

%package -n gtk2-metatheme-adwaita
Summary:        GTK+ 2 support for the Adwaita GNOME theme
Group:          System/GUI/GNOME
# the theme is using the pixmap engine, shipped inside gtk2
Requires:       gtk2
Requires:       gtk2-theming-engine-adwaita = %{version}
Requires:       metatheme-adwaita-common = %{version}
Supplements:    packageand(metatheme-adwaita-common:gtk2)
BuildArch:      noarch

%description -n gtk2-metatheme-adwaita
Adwaita is the default GNOME theme in GNOME 3.

# Note: it's really a metatheme, and not just a gtk3 theme as we require metatheme-adwaita-common

%package -n gtk3-metatheme-adwaita
Summary:        GTK+ 3 support for the Adwaita GNOME theme
Group:          System/GUI/GNOME
Requires:       cantarell-fonts
Requires:       metatheme-adwaita-common = %{version}
Supplements:    packageand(metatheme-adwaita-common:gtk3)
BuildArch:      noarch

%description -n gtk3-metatheme-adwaita
Adwaita is the default GNOME theme in GNOME 3.

%package -n gtk2-theming-engine-adwaita
Summary:        Adwaita GTK+ Theming Engine
Group:          System/GUI/GNOME

%description -n gtk2-theming-engine-adwaita
Adwaita is the default GNOME theme in GNOME 3.

%package -n gnome-themes-accessibility
Summary:        Accessibility GNOME Themes
Group:          System/GUI/GNOME
Conflicts:      gnome-themes < 3.0.0
BuildArch:      noarch

%description -n gnome-themes-accessibility
This package contains high-contrast and low-contrast themes for GNOME.

%package -n gnome-themes-accessibility-gtk2
Summary:        Accessibility GNOME Themes
Group:          System/GUI/GNOME
Requires:       gtk2-engine-hcengine
Supplements:    packageand(gnome-themes-accessibility:gtk2)
BuildArch:      noarch

%description -n gnome-themes-accessibility-gtk2
This package contains high-contrast and low-contrast themes for gtk2 applications.

%prep
%autosetup

%build
%configure
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%{icon_theme_cache_create_ghost HighContrast}
%fdupes %{buildroot}%{_datadir}/icons/Adwaita/cursors/
%fdupes %{buildroot}%{_datadir}/icons/HighContrast/
%fdupes %{buildroot}%{_datadir}/themes/

%post -n gnome-themes-accessibility
%icon_theme_cache_post HighContrast

# No need for %%icon_theme_cache_postun in %%postun since the theme won't exist anymore

%files -n metatheme-adwaita-common
%license LICENSE
%doc NEWS
%dir %{_datadir}/themes/Adwaita
%{_datadir}/themes/Adwaita/index.theme
%dir %{_datadir}/themes/Adwaita-dark
%{_datadir}/themes/Adwaita-dark/index.theme

%files -n gtk2-metatheme-adwaita
%{_datadir}/themes/Adwaita/gtk-2.0/
%{_datadir}/themes/Adwaita-dark/gtk-2.0/

%files -n gtk3-metatheme-adwaita
%{_datadir}/themes/Adwaita/gtk-3.0/
%dir %{_datadir}/themes/Adwaita-dark/gtk-3.0
%{_datadir}/themes/Adwaita-dark/gtk-3.0/gtk.css

%files -n gtk2-theming-engine-adwaita
%{_libdir}/gtk-2.0/2.10.0/engines/libadwaita.so

%files -n gnome-themes-accessibility
%ghost %{_datadir}/icons/HighContrast/icon-theme.cache
%{_datadir}/icons/HighContrast/
%dir %{_datadir}/themes/HighContrast/
%{_datadir}/themes/HighContrast/index.theme
%{_datadir}/themes/HighContrast/gtk-3.0/

%files -n gnome-themes-accessibility-gtk2
%{_datadir}/themes/HighContrast/gtk-2.0/

%changelog
* Tue Mar  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: the -32bit packages are no longer needed and
  have not been part of Tumbleweed for a while already (build for
  i586 only enabled in LegacyX86).
* Thu Mar 22 2018 bjorn.lie@gmail.com
- Update to version 3.28:
  + Fix HC index.theme generation.
  + Fix typo.
* Sat Mar 10 2018 jengelh@inai.de
- Update descriptions.
* Fri Mar  2 2018 bjorn.lie@gmail.com
- Update to version 3.27.92:
  + Distribute README.md and LICENSE (again).
- Rename package from gnome-themes-standard to gnome-themes-extra.
- Drop License source, fixed upstream.
- Drop translations-update-upstream BuildRequires: Not in use since
  GNOME 3.8, since the translations was dropped then.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Feb 20 2018 fcrozat@suse.com
- Ensure gtk2-32bit engine has the proper supplements to be
  automatically selected.
* Wed Feb 14 2018 dimstar@opensuse.org
- Update to version 3.27.90:
  + Rename to gnome-themes-extra.
  + Update README.md, various metafile updates.
  + Fix out-of-tree HC builds.
  + Use zopflipng.
  + Icon theme metadata updates.
  + Updated translations.
* Thu Mar 23 2017 zaitor@opensuse.org
- Update to version 3.22.3:
  + Dark theme fix.
  + Minor tweaks.
* Thu Oct  6 2016 zaitor@opensuse.org
- Update to version 3.22.2:
  + Dark theme updates.
  + Adwaita updates.
- Modify fdupes following upstream changes.
- Conditionally apply translations-update-upstream BuildRequires
  and macro for non-openSUSE only.
* Mon Oct  3 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Gtk2 dark variant.
  + Updated translations.
* Fri May 27 2016 idonmez@suse.com
- Update to GNOME 3.20.2 FATE#318572
* Sun May 15 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Scrollbar tweaks.
  + Makefile updates.
  + Updated translations.
* Wed Mar 23 2016 dimstar@opensuse.org
- Update to version 3.20:
  + No changes.
* Fri Mar  4 2016 dimstar@opensuse.org
- Update to version 3.19.91:
  + Updated gtk2 theme.
- Drop gnome-themes-standard-gtk3-like-menubar.patch: fixed
  upstream.
* Wed Dec 23 2015 damjanovic.ivo@gmail.com
- Add gnome-themes-standard-gtk3-like-menubar.patch: Make gtk2
  menubar like gtk3 (bgo#747679).
* Mon Dec 21 2015 fcrozat@suse.com
- Move gtk2 accessibility theme to a subpackage, which will be
  suggested when main accessibility package and libgtk-2_0-0 are
  installed.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed May 13 2015 zaitor@opensuse.org
- Update to version 3.16.2:
  + Updated translations.
* Tue Mar 24 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Sat Feb 21 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Drop metacity theme.
  + Drop polari icon.
* Fri Jan 23 2015 zaitor@opensuse.org
- Update to version 3.15.2.2:
  + HC: remove one more duplicate app icon.
- Changes from version 3.15.2.1:
  + Remove some HC app icons that are already shipped with apps.
* Fri Jan 23 2015 zaitor@opensuse.org
- Update to version 3.15.2:
  + Update gtk2 theme (entries, spinbuttons, radios, checks...).
  + Update HC icon names.
  + Update gtk2 HC icons.
* Fri Jan 23 2015 dimstar@opensuse.org
- Update to version 3.14.2.3:
  + HC: remove one more duplicate app icon.
- Changes from version 3.14.2.2:
  + Remove some HC app icons that already ship with apps.
- Changes from version 3.14.2.1:
  + Update gtk2 HC icons.
* Mon Nov 24 2014 dimstar@opensuse.org
- Drop creation of HighContrastInverse and LowContrast Icon theme
  caches: there is no icon available in those sets (boo#906721).
* Thu Nov 13 2014 zaitor@opensuse.org
- Update to version 3.14.2:
  + Update gtk2 theme (entries, spinbuttons, radios, checks...).
  + Update HC icon names.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + HighContrast checkbox updates.
  + Mutter theme updates
  + HighContrast icon theme additions.
* Fri Aug 22 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Checkbox/radio updates.
  + Improvements to the high contrast theme.
  + Move default background to gnome-backgrounds.
* Tue Jul 22 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Drop duplicate properties from metacity geometry.
  + Keep a dummy gtk.css for Adwaita.
- Reintroduce gtk3-metatheme-adwaita subpackage to carry the dummy
  gtk.css for Adwaita.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.3:
  + Major code refactor using SASS.
  + Moved gtk3 parts of the theme into gtk+.
- Remove gtk3-metatheme-adwaita subpackage: its content is provided
  by GTK+ 3.13, but in form of internal resources (so no separate
  package). libgtk-3-0 obsoletes gtk3-metatheme-adwaita.
* Wed May  7 2014 zaitor@opensuse.org
- Update to version 3.13.1:
  + Window borders on dark variant.
  + File chooser styling improvements.
  + Move cursors to the adwaita-icon-theme.
  + Remove text-shadow form switches in headerbars.
* Tue Mar 25 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Stable release, no change since 3.11.92.
* Fri Mar 21 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Message dialog buttons have no border.
  + Default buttons in message dialogs use the suggested button
    style.
  + Context menu fixes.
  + Gedit specific style tweaks.
  + Match pixel size of regular and image buttons in headerbars.
  + Linked button radius tweaks.
* Sat Feb 22 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Style for popover menus.
  + Improve OSD style.
  + Improve insensitive suggested-action buttons.
  + Gedit specific fixes.
  + Enable window dragging on toolbar separators.
* Wed Feb  5 2014 zaitor@opensuse.org
- Update to version 3.11.5:
  + New style for GtkDialog and GtkAssistant.
  + New backgrounds for 3.12.
  + Improvements to the new notebook tabs style.
  + Style for GtkActionBar.
  + Style for GtkPopover.
  + Fix GtkHeaderBar vertical padding.
  + Misc improvements for chooser buttons.
  + Separate GTK and GNOME styles better.
  + Gnome-bluetooth specific fixes.
  + Gedit specific fixes.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + New tabs (plain gtk, no more engines).
  + Headerbar/CSD fixes.
  + Gedit improvements.
  + Less contrasty/3D look for troughs (and pushed buttons).
* Tue Sep 24 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Gedit specific tweaks.
  + Expose close button in tabs better.
  + Abrt high contrast icon fix.
  + CSD decoration fixes.
  + Color definition cleanup.
  + GTK menu border fix when running outside of gnome-shell
    (bgo#707358).
* Tue Sep  3 2013 dimstar@opensuse.org
- Update to version 3.9.91:
  + GTK3:
  - Improve support for headerbars styling.
  - Increase legibility of pushed button style.
  - Fix CSD shadows for dark themed windows.
  - Fix dim-label color on selected rows.
  - Fix font style for context menus.
  - Fixes for destructive/suggested-action buttons.
  - App specific fixes for Baobab, Nautilus.
  + HighContrast:
  - Add support for CSD and headerbars.
  - Fix insensitive menu items styling.
  - Fix extra frame for GtkStatusbar.
  - App specific fixes for Nautilus.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + New style for WM buttons to go together with the new headerbar
    controls.
  + GTK3:
  - Improved client side decorations.
  - New radiobuttons and checkboxes.
  - HIDPI support.
  - Unified infobar styling.
  - App specific fixes for Contacts and Baobab.
* Fri Jun 21 2013 dimstar@opensuse.org
- Update to version 3.9.3:
  + Wallpaper update for 3.10
  + Add HC icon for system-software-update
  + GTK3:
  - Initial support for GTK client side decorations.
  - Adapt to changes in GTK master state propagation.
  - Add support for activity on top of GdMainView cells.
  - Improve theming for GEdit, Baobab.
* Tue Apr 16 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + GTK3:
  - Improve style of GtkScale's trough.
  - Add prelight and dark variants of pane separator grip assets.
  - Add a style class for Photos emblems.
  - Add support for dark theme to Documents-style collection
    icons.
  - Add support for selection rubberbands in content-view.
  - Add a workaround for backdrop selected text in Evolution.
  - Fix text selection in GEdit's search entry.
  + GTK2:
  - Improve style of GtkScale's trough.
* Mon Mar 25 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Update HC icons from gnome-icon-theme-symbolic.
  + Updated translations.
* Thu Mar 21 2013 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Tue Mar 19 2013 zaitor@opensuse.org
- Update to version 3.7.92:
  + GTK3:
  - Add theming support for GtkBubbleWindow text touch selections.
  - Fix clipped border in OSD frames.
  - Fix unmatching selection mode border width for header bars.
  - Update Baobab theming for latest master.
* Tue Mar  5 2013 dimstar@opensuse.org
- Update to version 3.7.91:
  + GTK3:
  - Support linked entries on primary toolbars.
  - Use stock GTK style for expanders.
  - Make progressbar colors darker in backdrop.
  - Fix insensitive state of OSD scales and buttons.
  - Fix a minor glitch in spinbuttons in RTL mode.
  - Fix some glitches in header bar style.
  - Fix content view checkboxes in backdrop.
  - Remove special case of Nautilus pathbar buttons.
  + GTK2:
  - Fix white border around background when overridden.
  - Fix a regression in Chrome/Chromium toolbar drawing.
  + WM:
  - Fix centering of the window title.
* Wed Feb 20 2013 dimstar@opensuse.org
- Update to version 3.7.90:
  + GTK3:
  - Add support for styling of header bar widgets.
  - Add support fof OSD buttons in a GtkOverlay.
  - Improve style for pressed OSD buttons.
  - Update gedit search slider CSS.
  - Added a style for Contacts' selection toolbar.
  - Fix Epiphany's toolbar buttons in dark theme.
  + GTK2:
  - Fix a regression in drawing Libreoffice/OO.o GtkEntry
    backgrounds.
  - Don't render a stroke for GTK_SHADOW_NONE frames.
* Wed Feb 13 2013 dimstar@opensuse.org
- Update to version 3.7.6:
  + Fix a bug with GdMainIconView checkbox assets.
  + Fix some build errors.
- Drop -lang package: the translations are merged into the themes,
  and there is no reason for the translations to be installed.
- No longer provide %%{name} by the -common package: this was only
  used for the -lang packages to be installable.
- Obsolete the -lang package from gnome-themes-common, as the -lang
  package is now gone.
* Fri Feb  8 2013 dimstar@opensuse.org
- Update to version 3.7.5:
  + Improve paddings for buttons on main toolbars.
  + Make it possible to override GtkEntry's background color in
    GTK2.
  + Add a workaround to render correctly OpenOffice.org scrollbars
    in GTK2.
  + Fix GtkFrame with labels not showing a stroke in GTK2.
  + Add some missing selectors for the SELECTED check/radio states
    in GTK2.
  + Use arrows of the same shape for all four directions in GTK2.
  + Add HC icons for new Settings panels.
  + Don't insall translations.
  + Fix missing check/radio buttons for content-view widgets.
  + Set padding for the SushiFontWidget preview widget.
* Fri Jan 18 2013 dimstar@opensuse.org
- Update to version 3.7.4:
  + Use a blue shade for the selection toolbar pattern.
  + Add a style for EvinceView document frames.
  + Improve linked buttons, insensitive state, OSD and floating bar
    styles in HC.
  + Improve selections in listbox widgets.
  + Add HC icon for gnome-dictionary.
  + Add runtime checks for X11-specific code.
  + Fix spurious border with Epiphany 3.7.
* Fri Jan 18 2013 dimstar@opensuse.org
- Update to version 3.7.3:
  + Don't repeat background image assets for radio/checks.
  + Use a light noise texture for content-view backgrounds.
  + Add a style for OSD views and scrollbars.
  + Improve style for listbox views.
  + Remove GtkViewport background color by default.
  + Improve style for dragged column-header buttons.
  + Update HighContrast icons.
  + Fix asymmetric borders in column-header buttons.
  + Fix coloring of GtkScale mark labels.
  + Fix GTK2 toolbar style for SWT applications.
  + Fix coloring of Eclipse tooltips.
  + Fix buggy rendering of menus in Opera.
* Fri Jan 18 2013 dimstar@opensuse.org
- Update to version 3.7.2:
  + Use .background instead of GtkWindow to style the window
    background.
  + Fix insensitive menu items background.
  + Add a box-shadow in inline toolbars.
  + Tweak paddings in toolbars.
  + Improve theming support for Baobab.
* Thu Jan 17 2013 dimstar@opensuse.org
- Add baselibs.conf: provide the engines as -32bit packages. This
  resolves 'warnings' invoked by 32bit binaries using GTK (like,
  for example, firefox/aurora packages from mozilla directly).
* Tue Nov 13 2012 dimstar@opensuse.org
- Update to version 3.6.2:
  + Add assets for insensitive radio/check states for the GTK2
    theme.
  + Fix active spinner when no animations are in use.
  + Fix gray menu separators under some circumstances.
  + Fix the build on non-X11 environments.
  + Fix uneven padding on the notebook tab close button.
  + Fix minor glitch with borders of tiled WM decorations.
- Replace pkgconfig(gdk-x11-2.0) BuildRequires with
  pkgconfig(gdk-2.0), following upstream.
* Tue Oct 16 2012 dimstar@opensuse.org
- Update to version 3.6.1:
  + Add a matching HighContrast WM theme
  + Add support for vertically oriented inline toolbars
  + Fix wrong background for raised and backdrop insensitive
    toolbar buttons
  + Fix glitches in selection-toolbar and suggested-action styling
  + Fix menu borders not present when not running under GNOME Shell
  + Fix color for selected desktop icons
  + Fix stray text shadows in inline toolbar buttons
  + Fix wrong background color when using a menu button in an OSD
    toolbar
  + Fix some glitches in notebook's tab rendering
  + Improve theming support for Nautilus, Documents, Evince, GEdit,
    Baobab and more.
- Create new gtk2-theming-engine-adwaita subpackage: there is a new
  gtk2 engine.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0.2:
  + Add hover/active states for slider assets.
  + Fix wrong border color for primary/inline toolbar buttons.
  + Fix wrong shadow direction in dark variant primary/inline
    toolbar buttons.
  + Fix color of icons on vertical spinbuttons.
  + Fix color of separators on toolbars.
  + Fix unwanted shadow from menubutton dropdow.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 3.6.0.1:
  + Revert "borders: fix fallout from SVG->PNG conversion".
- Changes from version 3.6.0:
  + Improve theming for sidebar scrollbars.
  + Render PNG images for borders.
  + Fix regression wrt. GtkScrolledWindow default background.
  + Fix insensitive active GtkSwitch borders.
  + Fix theming for GtkMenuToolButtons on inline toolbars.
  + Fix Epiphany toolbar theming for RTL layouts.
* Tue Sep 18 2012 dimstar@opensuse.org
- Update to version 3.5.92:
  + Adwaita:
  - New improved assets for the GTK2 implementation
  - Improve theming for progressbars in GtkEntry
  - Improve theming for vertical spinbuttons
  - Add transitions to and from GtkEntry's focused state
  - Add support for theming text selection handles
  - Fix GtkSpinner animation
  - Fix blue border for insensitive default buttons
  - Fix wrong highlight color for highlighted headings in
    GtkAssistant
  - Drop HighContrastInverse/LowContrast GTK themes
  + HighContrast:
  - Add new application icons
  - Don't show focus ring by default
  - Fix selected text theming under some circumstances
  - Fix theming for the deprecated GtkStyle fallback path
  - Fix GtkLevelBar theming
  - Fix theming for fallback GNOME Pane.
* Fri Sep  7 2012 vuntz@opensuse.org
- Change gtk2-engine-clearlooks Requires in gtk2-metatheme-adwaita
  to gtk2: the theme is now using the pixmap engine, which is
  shipped as part of GTK+.
* Tue Sep  4 2012 dimstar@opensuse.org
- Update to version 3.5.91:
  + Add support for vertically oriented spinbuttons.
  + Add support for a selection-menu button in selection mode.
  + Set scrolled windows background for normal and backdrop states.
  + Use new tooltip radius and alpha style properties for GTK2.
  + Use new range warp slider style property for GTK2.
  + Fix Chrome/Chromium custom menu items for GTK2.
  + Fix wrong text color in app notification widgets.
  + Fix tiny padding in Nautilus pathbars.
  + Fix stray background color below checkboxes in content views.
  + Synchronize HighContrast icons from the symbolic theme.
* Tue Aug 21 2012 dimstar@opensuse.org
- Update to version 3.5.90.1:
  + Fix missing GTK2 theme image assets.
  + Fix unwanted border on backdrop column headers.
* Mon Aug 20 2012 dimstar@opensuse.org
- Update to version 3.5.90:
  + Add a GTK2 version of Adwaita, based on the Bridge theme.
  + New default wallpapers.
  + Improve metacity attached dialog styling.
  + Improve custom theming for Nautilus.
  + Add generic theming support for selection-mode toolbar style
    classes.
  + Add generic theming support for in-app notifications.
  + Add generic theming support for suggested-action buttons.
  + Improve theming for GtkMenuButton.
* Wed Aug  8 2012 dimstar@opensuse.org
- Update to version 3.5.5:
  + Don't use a blue border for focused buttons.
  + Use CSS gradients instead of GTK gradients.
  + Improve styling for GtkLevelBar.
  + Improve bottom tab styling.
  + Improve theming support for Nautilus.
  + Add support for new Baobab style.
* Tue Jul 17 2012 dimstar@opensuse.org
- Update to version 3.5.4:
  + Don't use wildcard selectors for background colors.
  + Update WM style for attached modal dialogs.
  + Add support for the .gtkstyle-fallback selectors.
  + Add support for GtkMenuButton and GtkLevelBar.
  + Add support for symbolic images inside views.
  + Fix floating bars in dark variant.
  + Fix nautilus desktop icon color in dark variant.
* Mon Jun 25 2012 dimstar@opensuse.org
- Update to version 3.5.3:
  + Fix jumping combobox size between normal and backdrop states.
  + Fix spinbutton borders, combobox entries and resize grips in
    HighContrast.
  + Add support for GdTaggedEntry in the dark theme.
  + Use .scale and not GtkScale for selectors.
* Thu Jun  7 2012 dimstar@opensuse.org
- Update to version 3.5.2:
  + Use multiple CSS backgrounds to render
  - progressbar patterns
  - switch sliders
  - pane separator grips
  + Improve HighContrast/HighContrastInverse themes to mockups
  + Improve support for OSD toolbars/overlays/buttons
  + Add support for overlay progressbars, as seen in Web
  + Add support for vertically linked buttons
  + Add an option to disable building of the GTK3 engine
  + Update highcontrast icon theme to latest g-i-t-s content
  + Improve separator line colors
  + Fix wrong background color of check/radios in treeviews
  + Fix uneven padding for toolbar buttons
* Wed May 16 2012 dimstar@opensuse.org
- Update to version 3.5.1:
  + Rework HighContrast theme according to new mockups
  + Add theming support for OSD style
  + Render borders for GtkFrame; remove its padding
  + Improve fallback mode theming
  + Fix theming for fail whale dialog
  + Fix notebook tab background rendering
  + Update for GTK master CSS syntax changes
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 3.4.2:
  + Fix gnome-contacts' toolbar separator line
  + Fix Nautilus' inactive pane background color
  + Don't generate GTK icon cache when DESTDIR is set
* Tue Apr 17 2012 vuntz@opensuse.org
- Update to version 3.4.1:
  + Fix text shadow on active GtkLinkButton state and Documents
    selection toolbar
  + Fix opaque background for tooltips children
  + Fix text spacing in progress bars
  + Fix cell renderer progress bar border rendering
  + Fix double background in fallback panel menuitem images
  + Fix insensitive state for treeview column header buttons
* Mon Mar 26 2012 vuntz@opensuse.org
- Update to version 3.4.0:
  + Fix notebook tab gradient scaling
  + Fix missing border in the screensaver unlock dialog
* Tue Mar 20 2012 vuntz@opensuse.org
- Update to version 3.3.92:
  + Add HighContrast icon theme generated from
    gnome-icon-theme-symbolic
  + Don't make floating bars yellow
  + Fix text shadows in active+insensitive toolbar buttons
  + Fix right WM border in focused left tiled windows
  + Add no-highlight versions of insensitive radio/check assets for
    use in treeviews
  + Fix expander radius in treeviews
  + Fix color for 'image' style class over a selected background
  + Fix GtkTreeView separators on hover and backdrop states
  + Fix color of dim labels in treeview renderers
  + Fix border for buttons in NautilusQueryEditor infobars
  + Add styling for gedit's not-found search entry style class
- Add pkgconfig() BuildRequires for new build dependencies to
  create HighContrast icon theme: cairo, gdk-3.0, gdk-pixbuf-2.0,
  gio-2.0.
* Tue Mar  6 2012 vuntz@opensuse.org
- Update to version 3.3.91:
  + Use bright color for text on high-saturation infobars
  + Theme GtkColorChooser dark variation
  + Theme junction between scrollbars
  + Fix missing GtkSpinner animation
  + Fix wrong color for focused dim-labels
  + Fix insensitive state for GtkTreeView and GtkIconView
  + Update Documents theming for 0.3.91
  + Remove gedit sidepane custom styling for 3.4
* Wed Feb 22 2012 vuntz@opensuse.org
- Update to version 3.3.90.1:
  + Theme GtkColorChooser backdrop state
  + Fix borders for primary toolbar combobox entries on primary
    toolbars
  + Fix background not properly clipped on GtkSwitch and troughs
  + Fix background color of selected rows for Documents
  + Fix Terminal colors in HighContrast/HighContrastInverse
  + Fix text shadow for raised active buttons
* Tue Feb 21 2012 vuntz@opensuse.org
- Update to version 3.3.90:
  + Rewrite HighContrast/HighContrastInverse themes
  + Theming support for GtkColorChooser
  + Fix selections in backdrop state
  + Convert more assets to PNG images
  + Improvements in the dark WM theme
  + Fix base background compatibility with GtkStyle-using
    applications
  + Don't set a padding for GtkViewport
  + Fix styling for Gucharmap
* Wed Feb  8 2012 vuntz@opensuse.org
- Update to version 3.3.5.1:
  + Fix gedit/Epiphany tabs
  + Fix wrong selected text color
* Tue Feb  7 2012 vuntz@opensuse.org
- Update to version 3.3.5:
  + Use GTK resource file support
  + Use PNG assets instead of SVG
  + Remove the window resize grip
  + Don't set child-displacement-y on buttons
  + Don't set WM title/button borders on frameless windows
  + Improve check/radio and slider assets
  + Adapt to GTK+ master changed for:
  - border/padding/margin units
  - entry/combobox border allocations
  - GtkImage backgrounds
- Remove xz BuildRequires now that it comes for free in the build
  system.
- Add gdk-pixbuf-loader-rsvg BuildRequires: this is needed at build
  time to convert svg files to GdkPixbuf pixdata in GResource.
* Tue Jan 17 2012 vuntz@opensuse.org
- Update to version 3.3.4:
  + Implement support for the backdrop state
  + New scrollbar design
  + Improved support for Epiphany, Nautilus and GEdit
  + Improve nighttime background
  + Many smaller detail tweaks and fixes
  + Adapt to GTK+ master changes for:
  - Button border allocations
  - New CSS parser stricter spec-compliant syntax
* Fri Jan 13 2012 vuntz@opensuse.org
- Change gtk2-engines Requires to gtk2-engine-clearlooks in
  gtk2-metatheme-adwaita, now that gtk2-engines has split packages
  (see bnc#706929).
- Add explicit gtk2-engine-hcengine Requires to
  gnome-themes-accessibility: the GTK+ 2 theme is using the
  hcengine engine.
* Mon Dec 19 2011 vuntz@opensuse.org
- Update to version 3.3.3:
  + Big theme revamp; better details and niceties all around
  + Theming for new horizontal GtkSpinButtons
  + Implement border-only style for maximized windows
  + Use an animated wallpaper changing troughout the day
  + Better error messages for missing build dependencies
- Add xz BuildRequires because we can't build a package for a
  xz-compressed tarball without explicitly specifying that... See
  bnc#697467 for more details.
* Mon Nov 21 2011 dimstar@opensuse.org
- Update to version 3.3.2:
  + Initial implementation of selection-mode, dropdown and OSD
    toolbars for GNOME Documents.
  + Don't set a padding for GtkNotebook children.
  + Fix focus border color for iconview cells.
  + Don't override prelight color for dim-label.
  + Fix for Nautilus migrating GtkTable->GtkGrid.
* Thu Oct 27 2011 dimstar@opensuse.org
- Update to version 3.3.1:
  + Use a new wallpaper
  + Improve notebook tabs padding
  + Enable transparency and rounded corners for tooltips
  + Correctly theme GtkSwitch for the dark variant
* Tue Oct 18 2011 vuntz@opensuse.org
- Update to version 3.2.1:
  + Fix gnome-panel theming for fallback mode
- Drop gnome-themes-standard-fallback-improvements.patch: fixed
  upstream.
* Wed Oct  5 2011 vuntz@opensuse.org
- Add gnome-themes-standard-fallback-improvements.patch: fixes from
  git to make fallback mode look better.
* Wed Sep 28 2011 vuntz@opensuse.org
- Update to version 3.2.0.2:
  + Revert to the previous wallpaper
* Tue Sep 27 2011 vuntz@opensuse.org
- Update to version 3.2.0.1:
  + Update the default wallpaper for 3.2
* Mon Sep 26 2011 vuntz@opensuse.org
- Update to version 3.2.0:
  + Fix pressed state of inline toolbar buttons
* Tue Sep 20 2011 vuntz@opensuse.org
- Update to version 3.1.92:
  + Improve theming for radio/check menuitems for insensitive and
    mixed states
  + Move applications overrides into a separate stylesheet
  + Improve pathbar active button styling
  + Remove highlight from active button border
  + Add selectors for the DND style class
  + Support RTL mode for GtkComboBox entries
  + Improve attached modal dialogs
* Tue Sep  6 2011 vuntz@opensuse.org
- Update to version 3.1.91:
  + Make the text color for insensitive menu entries a bit darker
  + Use stock gtk_render_line() implementation from
    GtkThemingEngine
  + Apply a linked style for filechooser pathbar buttons
* Tue Aug 30 2011 vuntz@opensuse.org
- Update to version 3.1.90:
  + Use a flat style for radiobuttons on sidebars
  + Enable raised/linked areas on non-primary toolbars
  + Support menubar toolbars
  + Support menu active state for button
  + Fix tooltips background
  + Fix fail whale dialog button prelight
* Tue Aug 16 2011 dimstar@opensuse.org
- Update to version 3.1.5:
  + Improve WM theme for titlebars and buttons
  + Improve buttons, scales, sliders, progressbars for the dark
    theme
  + Use a new style for GtkComboBox widgets with entries
  + Fix combobox left/right padding
  + Improve GtkTreeView expander styling
  + Prelight the spinbutton arrows
  + Use the new gtk-focus-visible Gtk setting
  + Fix trough style class matching for custom widgets
* Mon Jul 25 2011 vuntz@opensuse.org
- Update to version 3.1.4:
  + Update the dark theme with a blue selection color
  + Use the raised style for buttons in inline-toolbars
  + Revert to light colors for the menus now that the mutter
    shadows are fixed
  + Build fixes
- Change gtk3-devel BuildRequires to pkgconfig(gtk+-3.0).
- Add pkgconfig(librsvg-2.0) BuildRequires: it's a new dependency.
* Sat Jul  2 2011 vuntz@opensuse.org
- Update to version 3.1.3:
  + Fix borders and background for vertical progressbars
  + Fix horizontal padding for progressbars in GtkEntry
  + Add a subtle gradient to the active notebook tab
  + Improve styling for GtkComboBox with entries
  + Improve insensitive style for the dark theme
* Mon Jun 27 2011 vuntz@opensuse.org
- Update to version 3.1.2.1:
  + Fix a regression with padding in GtkSpinButtons and GtkEntries
- Changes from version 3.1.2:
  + Use SVG assets to render border image gradients
  + Use SVG assets to render scale sliders
  + Remove custom inset style properties
  + Render shadows for toolbar buttons
  + Improve GtkAssistant theming
  + Improve GtkTreeView column headers
  + Improve GtkProgressbar, sliders and GtkEntry for the dark theme
- Changes from version 3.1.1:
  + Reintroduce the dark theme variant
  + Add inset shades on various elements
  + Render the menus fill in dark
  + Tweak GtkSwitch inactive label color
  + Fix progressbar gradients and GtkCellRendererProgress
  + Improve the maximized windows titlebar height
* Wed Apr 27 2011 fcrozat@novell.com
- Update to version 3.0.1:
  + Reduce vertical padding for most of the common widgets,
    requires GTK+ 3.0.9.
* Wed Apr 27 2011 vuntz@opensuse.org
- Move accessibility themes to a gnome-themes-accessibility
  subpackage.
* Tue Apr  5 2011 fcrozat@novell.com
- Update to version 3.0.0:
  + Don't propagate an 1px separator width to the whole toolbar
  + Add icon-size property for NaTrayApplet
- Add Conflicts to gnome-themes < 3.0.0 because of accessibility
  themes.
* Mon Mar 28 2011 fcrozat@novell.com
- Update to version 2.91.93:
  + Remove the dark theme variant for 3.0
  + Fix gnome-terminal background
- Changes from version 2.91.92.1:
  + Theme fail whale dialog
  + Add a dark Adwaita variant
  + Add an inline toolbar style class
  + Add a sidebar style class
  + Fixes for insensitive state
  + Fix focus ring on primary toolbars
  + Tweak GTK2 theme colors
  + Theme GtkScale marks
  + Add an 1px spacing between scrollbar sliders and steppers
  + Theme menu arrows
  + Theme menu accelerators
  + Tweak GtkSwitch theming
  + Lots of tweaks for Fallback mode panel/applets
- Changes from version 2.91.91.1:
  + Add raised toolbar buttons
  + Make focus ring match latest mockups
  + Make active toolbar buttons match latest mockups
  + Fix pane separators
  + Properly align check/radio buttons
  + Fix a typo to work correctly with GTK+ 3.0.3
- Changes from version 2.91.91:
  + Big revamp of the Adwaita engine to match 3.0 designs.
- Accessibility themes are now in gnome-themes-standard package.
* Mon Feb 28 2011 fcrozat@novell.com
- Update to version 2.91.90.1:
  + Fix appearance of check boxes
- Changes from version 2.91.90:
  + Don't hardcode Cantarell in the CSS file
  + Miscellaneous rendering fixes
  + Separate theme colors from the CSS
  + Add a settings.ini file
- Changes from version 2.91.8:
  + Don't set background for evince background
  + Remove gtkrc file for GTK+ 3.0
  + Plain style for 'internal' toolbars
- Changes from version 2.91.7:
  + Improved resize grip rendering
  + Fix gnome-terminal text colors
  + Fix expander rendering +/- confusion
  + Fix install location of the engine
- Changes from version 2.91.5:
  + Add Adwaita engine
- Create subpackage for adwaita engine and remove
  gtk3-theming-engine-clearlooks requires in
  gtk3-metatheme-adwaita.
- Add gtk3-devel BuildRequires and stop marking the main package as
  noarch since we now have a arch-specific subpackage. Instead,
  mark metatheme-adwaita-common, gtk2-metatheme-adwaita and
  gtk3-metatheme-adwaita as noarch.
* Wed Dec 15 2010 vuntz@opensuse.org
- New package (version 2.91.4).
